@@ -29,7 +29,6 @@ use NewsExtractor::SiteSpecificExtractor::ctee_com_tw;
 use NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw;
 use NewsExtractor::SiteSpecificExtractor::newnet_tw;
 use NewsExtractor::SiteSpecificExtractor::www_thestandnews_com;
-use NewsExtractor::SiteSpecificExtractor::www_hkcnews_com;
 use NewsExtractor::SiteSpecificExtractor::www_epochtimes_com;
 use NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_idn_com_tw;
@@ -39,10 +38,13 @@ use NewsExtractor::SiteSpecificExtractor::www_twreporter_org;
 use NewsExtractor::SiteSpecificExtractor::new_ctv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::hk_crntt_com;
 use NewsExtractor::SiteSpecificExtractor::hk_on_cc;
+use NewsExtractor::SiteSpecificExtractor::www_hkcna_hk;
+use NewsExtractor::SiteSpecificExtractor::www_hkcnews_com;
 use NewsExtractor::SiteSpecificExtractor::www_xinhuanet_com;
 use NewsExtractor::SiteSpecificExtractor::news_cctv_com;
 use NewsExtractor::SiteSpecificExtractor::focustaiwan_tw;
 use NewsExtractor::SiteSpecificExtractor::newtalk_tw;
+use NewsExtractor::SiteSpecificExtractor::www_digitimes_com_tw;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -100,12 +102,20 @@ use constant {
         'new.ctv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::new_ctv_com_tw',
         'hk.crntt.com' => 'NewsExtractor::SiteSpecificExtractor::hk_crntt_com',
         'hk.on.cc' => 'NewsExtractor::SiteSpecificExtractor::hk_on_cc',
+        'www.hkcna.hk' => 'NewsExtractor::SiteSpecificExtractor::www_hkcna_hk',
         'www.xinhuanet.com' => 'NewsExtractor::SiteSpecificExtractor::www_xinhuanet_com',
         'news.cctv.com' => 'NewsExtractor::SiteSpecificExtractor::news_cctv_com',
         'focustaiwan.tw' => 'NewsExtractor::SiteSpecificExtractor::focustaiwan_tw',
         'newtalk.tw' => 'NewsExtractor::SiteSpecificExtractor::newtalk_tw',
+        'www.digitimes.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_digitimes_com_tw',
     },
     CSSRuleSetByHost => {
+        'www.cw.com.tw' => {
+            headline => 'div.article__head h1',
+            dateline => 'div.article__detail > time',
+            journalist => 'div.author--item > a',
+            content_text => 'div.article__content',
+        },
         'www.taiwannews.com.tw' => {
             headline => 'h1.article-title',
             dateline => 'div.article-date',
